searchNodes=[{"ref":"ExGtin.html","title":"ExGtin","type":"module","doc":"Documentation for ExGtin. This library provides functionality for validating GTIN compliant codes."},{"ref":"ExGtin.html#check_gtin/1","title":"ExGtin.check_gtin/1","type":"function","doc":"Check for valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns {:ok} or {:error} Examples iex&gt; ExGtin.check_gtin(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.check_gtin(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;}"},{"ref":"ExGtin.html#generate/1","title":"ExGtin.generate/1","type":"function","doc":"Generates valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns code with check digit Examples iex&gt; ExGtin.generate(&quot;629104150021&quot;) &quot;6291041500213&quot; iex&gt; ExGtin.generate(&quot;62921&quot;) {:error, &quot;Invalid GTIN Code Length&quot;}"},{"ref":"ExGtin.html#generate_gtin/1","title":"ExGtin.generate_gtin/1","type":"function","doc":"Generates valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns code with check digit Examples iex&gt; ExGtin.generate_gtin(&quot;629104150021&quot;) &quot;6291041500213&quot; iex&gt; ExGtin.generate_gtin(&quot;62921&quot;) {:error, &quot;Invalid GTIN Code Length&quot;}"},{"ref":"ExGtin.html#gs1_prefix_country/1","title":"ExGtin.gs1_prefix_country/1","type":"function","doc":"Find the GS1 prefix country for a GTIN number Returns {atom, String.t()} Examples iex&gt; ExGtin.gs1_prefix_country(&quot;53523235&quot;) {:ok, &quot;GS1 Malta&quot;} iex&gt; ExGtin.gs1_prefix_country(&quot;6291041500214&quot;) {:ok, &quot;GS1 Emirates&quot;} iex&gt; ExGtin.gs1_prefix_country(&quot;9541041500214&quot;) {:error, &quot;No GS1 prefix found&quot;}"},{"ref":"ExGtin.html#validate/1","title":"ExGtin.validate/1","type":"function","doc":"Check for valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns {:ok} or {:error} Examples iex&gt; ExGtin.validate(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.validate(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;}"},{"ref":"ExGtin.Validation.html","title":"ExGtin.Validation","type":"module","doc":"Documentation for ExGtin. This library provides functionality for validating GTIN compliant codes."},{"ref":"ExGtin.Validation.html#check_code_length/1","title":"ExGtin.Validation.check_code_length/1","type":"function","doc":"Checks the code for the proper length as specified by the GTIN-8,12,13,14 specification Returns {atom, String.t()} Examples iex&gt; ExGtin.Validation.check_code_length([1,2,3,4,5,6,7,8]) {:ok, &quot;GTIN-8&quot;} iex&gt; ExGtin.Validation.check_code_length([1,2,3,4,5,6,7]) {:error, &quot;Invalid GTIN Code Length&quot;}"},{"ref":"ExGtin.Validation.html#find_gs1_prefix_country/1","title":"ExGtin.Validation.find_gs1_prefix_country/1","type":"function","doc":"Find the GS1 prefix country for a GTIN number Returns {atom, String.t()} Examples iex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;53523235&quot;) {:ok, &quot;GS1 Malta&quot;} iex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;6291041500214&quot;) {:ok, &quot;GS1 Emirates&quot;} iex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;9541041500214&quot;) {:error, &quot;No GS1 prefix found&quot;}"},{"ref":"ExGtin.Validation.html#generate_check_code_length/1","title":"ExGtin.Validation.generate_check_code_length/1","type":"function","doc":"When generating the code, checks the code for the proper length as specified by the GTIN-8,12,13,14 specification. The code should be -1 the length of the GTIN code as the check digit will be added later Returns {atom, String.t()} Examples iex&gt; ExGtin.Validation.generate_check_code_length([1,2,3,4,5,6,7]) {:ok, &quot;GTIN-8&quot;} iex&gt; ExGtin.Validation.generate_check_code_length([1,2,3,4,5,6]) {:error, &quot;Invalid GTIN Code Length&quot;}"},{"ref":"ExGtin.Validation.html#generate_check_digit/1","title":"ExGtin.Validation.generate_check_digit/1","type":"function","doc":"Generate check digit GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns number Examples iex&gt; ExGtin.Validation.generate_check_digit([6,2,9,1,0,4,1,5,0,0,2,1]) 3"},{"ref":"ExGtin.Validation.html#generate_gtin_code/1","title":"ExGtin.Validation.generate_gtin_code/1","type":"function","doc":"Generate valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns {atom, String.t()} Examples iex&gt; ExGtin.Validation.generate_gtin_code(&quot;629104150021&quot;) &quot;6291041500213&quot; iex&gt; ExGtin.Validation.generate_gtin_code(&quot;62921&quot;) {:error, &quot;Invalid GTIN Code Length&quot;}"},{"ref":"ExGtin.Validation.html#gtin_check_digit/1","title":"ExGtin.Validation.gtin_check_digit/1","type":"function","doc":"Check for valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes Returns {atom, String.t()} Examples iex&gt; ExGtin.Validation.gtin_check_digit(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.Validation.gtin_check_digit(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;}"},{"ref":"ExGtin.Validation.html#lookup_gs1_prefix/1","title":"ExGtin.Validation.lookup_gs1_prefix/1","type":"function","doc":"Looks up the GS1 prefix in a table GS1 Reference https://www.gs1.org/company-prefix Returns {atom, String.t()}"},{"ref":"ExGtin.Validation.html#mult_by_index_code/1","title":"ExGtin.Validation.mult_by_index_code/1","type":"function","doc":"By index, returns the corresponding value to multiply the digit by Returns number Examples iex&gt; ExGtin.Validation.mult_by_index_code(1) 1 iex&gt; ExGtin.Validation.mult_by_index_code(2) 3"},{"ref":"ExGtin.Validation.html#multiply_and_sum_array/1","title":"ExGtin.Validation.multiply_and_sum_array/1","type":"function","doc":"Calculates the sum of the digits in a string and multiplied value based on index order Returns number Examples iex&gt; ExGtin.Validation.multiply_and_sum_array([6,2,9,1,0,4,1,5,0,0,2,1]) 57"},{"ref":"ExGtin.Validation.html#subtract_from_nearest_multiple_of_ten/1","title":"ExGtin.Validation.subtract_from_nearest_multiple_of_ten/1","type":"function","doc":"Calculates the difference of the highest rounded multiple of 10 Returns number Examples iex&gt; ExGtin.Validation.subtract_from_nearest_multiple_of_ten(57) 3"},{"ref":"readme.html","title":"ExGtin","type":"extras","doc":"ExGtin A GTIN (Global Trade Item Number) &amp; UPC (Universal Price Code) Generation and Validation Library in Elixir under the GS1 specification."},{"ref":"readme.html#features","title":"ExGtin - Features","type":"extras","doc":"Supports GTIN-8, GTIN-12 (UPC-12), GTIN-13 (GLN), GTIN-14, GSIN, SSCC codes Generate GTIN Check GTIN validity Lookup GS1 country prefix"},{"ref":"readme.html#installation","title":"ExGtin - Installation","type":"extras","doc":"def deps do [{:ex_gtin, &quot;~&gt; 0.4.0&quot;}] end"},{"ref":"readme.html#usage","title":"ExGtin - Usage","type":"extras","doc":"Check GTIN codes iex&gt; ExGtin.validate(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.validate(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;} Generate GTIN codes iex&gt; ExGtin.generate(&quot;629104150021&quot;) &quot;6291041500213&quot; Lookup GS1 Prefix iex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;53523235&quot;) {:ok, &quot;GS1 Malta&quot;} Using Strings, Arrays or Numbers String iex&gt; ExGtin.validate(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} Array of Integers iex&gt; ExGtin.validate([6, 2, 9, 1, 0, 4, 1, 5, 0, 0, 2, 1, 3]) {:ok, &quot;GTIN-13&quot;} Integer iex&gt; ExGtin.validate(6291041500213) {:ok, &quot;GTIN-13&quot;} Integers with leading zeros may not process properly"},{"ref":"readme.html#reference","title":"ExGtin - Reference","type":"extras","doc":"GTIN How to calculate GTIN Documentation can be found at https://hexdocs.pm/ex_gtin on HexDocs."},{"ref":"readme.html#tests","title":"ExGtin - Tests","type":"extras","doc":"Run tests with mix test Run test coverage MIX_ENV=test mix coveralls"},{"ref":"readme.html#contributing","title":"ExGtin - Contributing","type":"extras","doc":"Please read CONTRIBUTING.md for details on our code of conduct, and the process for submitting pull requests to us. When making pull requests, please be sure to update the CHANGELOG.md with the corresponding changes. Please make sure that all tests pass and that the static analysis checker credo is run. Run static code analysis mix credo Generate Docs mix docs"},{"ref":"readme.html#sponsors","title":"ExGtin - Sponsors","type":"extras","doc":"This project is sponsored by KickinEspresso"},{"ref":"readme.html#versioning","title":"ExGtin - Versioning","type":"extras","doc":"We use SemVer for versioning. For the versions available, see the tags on this repository."},{"ref":"readme.html#code-of-conduct","title":"ExGtin - Code of Conduct","type":"extras","doc":"Please refer to the Code of Conduct for details"},{"ref":"readme.html#license","title":"ExGtin - License","type":"extras","doc":"This project is licensed under the MIT License - see the LICENSE.md file for details"},{"ref":"readme.html#publish","title":"ExGtin - Publish","type":"extras","doc":"mix hex.publish"}]